searchData={"items":[{"type":"module","title":"Elemental","doc":"> A Tailwind and DaisyUI based Phoenix components library.\n\nProvides a set of components built on top of DaisyUI and Tailwind\nfor use with Elixir Phoenix.\n\nProvided components aim to behave as close as possible to plain HTML\nelements and follow to best of my abilities Phoenix' conventions.\n\nSome functionality requires small set of JavaScript present, this is\nkept to a minimal as possible.","ref":"Elemental.html"},{"type":"module","title":"Installation - Elemental","doc":"Add the Elemental to your application's dependencies in your `mix.exs`\n\n    {:elemental, \"~> 0.1.0\"}\n\nUpdate your `app.js` to add the necessary hooks (required for JavaScript\nbased features)\n\n```javascript\n// assets/js/app.js\n\n// ... other imports\nimport * as Hooks from \"elemental\"\n\nconst hooks = { /* the hooks your app uses */ }\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, { hooks, ... })\n```","ref":"Elemental.html#module-installation"},{"type":"module","title":"Usage - Elemental","doc":"In your application you can simply `use` `Elemental` in to import\nall the components provided\n\n    defmodule MyAppWeb.Component do\n      use MyAppWeb, :html\n      use Elemental # now you can use components directly\n\n      def my_component(assigns) do\n      ~H\"\"\"\n      <!-- you can now Elemental's components here -->\n      \"\"\"\n      end\n    end\n\nAlternatively, you can import specific components as needed.","ref":"Elemental.html#module-usage"},{"type":"module","title":"Elemental.Breadcrumbs","doc":"> Exposing Daisy breadcrumbs as Phoenix components.","ref":"Elemental.Breadcrumbs.html"},{"type":"function","title":"Elemental.Breadcrumbs.breadcrumbs/1","doc":"A wrapper around DaisyUI's breadcrumbs.","ref":"Elemental.Breadcrumbs.html#breadcrumbs/1"},{"type":"function","title":"Attributes - Elemental.Breadcrumbs.breadcrumbs/1","doc":"* Global attributes are accepted.","ref":"Elemental.Breadcrumbs.html#breadcrumbs/1-attributes"},{"type":"function","title":"Slots - Elemental.Breadcrumbs.breadcrumbs/1","doc":"* `item` (required) - Specify the items in the breadcrumb.","ref":"Elemental.Breadcrumbs.html#breadcrumbs/1-slots"},{"type":"module","title":"Elemental.Dropdown","doc":"> An abstraction around DaisyUI's dropdown.\n\nThink of it as a more advanced `Elemental.Select` with support for\nmulti-select and searching out of the box.\n\nThis is implement in a manner that works drop-in in forms and uses\nonly dead/stateless components with minimal JavaScript.","ref":"Elemental.Dropdown.html"},{"type":"module","title":"Usage - Elemental.Dropdown","doc":"Make sure in your application to include the required JavaScript hooks\nrequired for the main behaviour, found in `dropdown.js`.\n\nSee the [hooks section](#javascript-hooks) for more details.\n\nMost basic usage is done by simply passing it `options`\n\n   <.dropdown options={[\"Foo\", \"Bar\"]}/>\n\nSee `dropdown/1` for details on the support properties and their behaviour.","ref":"Elemental.Dropdown.html#module-usage"},{"type":"module","title":"JavaScript hooks - Elemental.Dropdown","doc":"This implementation requires JavaScript hooks for it's main behaviour,\nutilizes 3 main hooks\n\n- `ElementalDropdownSearch` implementing filtering/search behaviour when enabled.\n- `ElementalDropdownSingleItem` implementing prompt changes when using single item mode.\n- `ElementalDropdownMultiItem` implementing prompt changes when using multi item mode.\n\n##","ref":"Elemental.Dropdown.html#module-javascript-hooks"},{"type":"function","title":"Elemental.Dropdown.dropdown/1","doc":"> The primary dropdown component.\n\nThis dropdown attempts to provide a fully featured dropdown/select element\nwith native support for searching along with multiple select mode out\nof the box.\n\n> The API provided here works drop-in with Elemental's select\n> component (see `Elemental.Select`).","ref":"Elemental.Dropdown.html#dropdown/1"},{"type":"function","title":"Implementation considerations - Elemental.Dropdown.dropdown/1","doc":"The component is implemented as a dead/stateless component as to simplify it's\nusage and avoid complexities associated with live/stateful components.\n\nThis comes from my dissatisfaction with implementations I found which have behaviours\nthat I kept finding to be non-obvious and odd, from how they interact with\nevents sent to parent vs themselves, along with how they handle their\nstates.\n\nAdditionally the implementation aims to be drop-in compatible with forms in general\nas well as how forms are handled in Phoenix/LiveView without requiring much fuss.\n\nThe behaviour relies heavily on the provided minimal JavaScript hooks, as well as\nrelying on native form behaviours with how forms deal with radio buttons and\ncheckboxes.","ref":"Elemental.Dropdown.html#dropdown/1-implementation-considerations"},{"type":"function","title":"Select compatibility - Elemental.Dropdown.dropdown/1","doc":"While this component provides 1-1 API compatibility the the more simpler\n`Elemental.Select.select/1`, augmenting it with additional features\nand interactivity, there's the caveat that it does not yet\nsupport option groups.","ref":"Elemental.Dropdown.html#dropdown/1-select-compatibility"},{"type":"function","title":"Attributes - Elemental.Dropdown.dropdown/1","doc":"* `options` (`:list`) (required) - The list of values to select between. This is required to either be a list of\n  strings, or a list of string tuples.","ref":"Elemental.Dropdown.html#dropdown/1-attributes"},{"type":"function","title":"List item types - Elemental.Dropdown.dropdown/1","doc":"- If given as a list of strings (`[String.t]`) each option will use that value\n    as both it's label and value sent to from the dropdown.\n  - If give as a list of tuples (`[{String.t, String.t}]`), those tuples are expected\n    to be two strings, the first being the label to use, while the second is\n    expected to be the value to send from the dropdown.\n  - Mixing the two forms is allowed.\n\n* `prompt` (`:string`) - The prompt to display for the the dropdown.\n\n  This value is replaced when a selection is made with the selected item's label\n  (requires JavaScript enabled in the browser).\n\n  Defaults to `nil`.\n* `name` (`:string`) - The name of the dropdown, if not given a random value is selected.\n* `value` (`:any`) - A value that is selected currently by the component.\n\n  Useful for either preselecting items or to maintaining selected\n  items state across rerenders.","ref":"Elemental.Dropdown.html#dropdown/1-list-item-types"},{"type":"function","title":"Type - Elemental.Dropdown.dropdown/1","doc":"- The type is required to either be a single string or a list of strings,\n    the values of it should correspond to the value (not label) of the\n    options (if using a list of strings then it's the same as label).\n  - If the type is single select and if the value is a list of more than one\n    item this will raise an error.\n\n  Defaults to `nil`.\n* `multi` (`:boolean`) - To enable selection of multiple values, passed to consumer as a list. Defaults to `false`.\n* `searchable` (`:boolean`) - To enable searching the options of the dropdown.\n\n  Search is performed by looking through the labels for the given\n  input as substring to match on, if it doesn't match the option\n  is disabled, deselected, and hidden.\n\n  #### Notes:\n  - Search is case-insensitive.\n  - This features JavaScript enabled in the browser along with Hooks enabled.\n\n  Defaults to `false`.\n* `searchable_inline` (`:boolean`) - To enable inlining of the search field for the dropdown (experimental/buggy). Defaults to `false`.\n* `align` (`:string`) - Specify the alignment for the dropdown. Defaults to `\"start\"`.\n* `from` (`:string`) - Specify where the dropdown will appear from. Defaults to `\"bottom\"`.\n* `hover` (`:boolean`) - To enable opening the dropdown on hover. Defaults to `false`.\n* `open` (`:boolean`) - To open the dropdown immediately. Defaults to `false`.\n* `color` (`:string`) - The dropdown prompt container color.Must be one of `\"ghost\"`, `\"neutral\"`, `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - The dropdown prompt container size.Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, `\"lg\"`, or `\"xl\"`.\n* `class` (`:string`) - Additional CSS classes to pass to the dropdown.\n\n  Those will be applied to the the dropdown prompt container since it's\n  the \"visible\"/\"interactive\" bit of the dropdown.\n\n  Defaults to `nil`.","ref":"Elemental.Dropdown.html#dropdown/1-type"},{"type":"module","title":"Elemental.Loading","doc":"> Exposing Daisy loaders as Phoenix components.","ref":"Elemental.Loading.html"},{"type":"function","title":"Elemental.Loading.loading/1","doc":"A wrapper around all DaisyUI's loading components.","ref":"Elemental.Loading.html#loading/1"},{"type":"function","title":"Attributes - Elemental.Loading.loading/1","doc":"* `type` (`:string`) - Specify the type of loader to use. Defaults to `\"spinner\"`.\n* `color` (`:string`) - Choose which color the loading component will be. Defaults to `\"primary\"`.\n* `size` (`:string`) - Choose which size the loading component will be. Defaults to `\"md\"`.\n* `screen_reader_text` (`:string`) - Set the hidden text intended for screen readers. Defaults to `\"Loading...\"`.","ref":"Elemental.Loading.html#loading/1-attributes"},{"type":"module","title":"Elemental.Select","doc":"> An abstraction on top of DaisyUI's (& plain HTML) select.\n\nThis abstracts native HTML selects providing an API that is compatible\n1-1 with `Elemental.Dropdown` aiming to provide consistency between\nthe main/core input components provided by Elemental.","ref":"Elemental.Select.html"},{"type":"module","title":"Usage - Elemental.Select","doc":"Most basic usage is done by simply passing it `options`\n\n   <.select options={[\"Foo\", \"Bar\"]}/>\n\nSee `select/1` for details on the support properties and their behaviour.","ref":"Elemental.Select.html#module-usage"},{"type":"function","title":"Elemental.Select.select/1","doc":"> The primary select component.","ref":"Elemental.Select.html#select/1"},{"type":"function","title":"Attributes - Elemental.Select.select/1","doc":"* `options` (`:list`) (required) - The list of values to select between. This is required to either be a list of\n  strings, or a list of string tuples.","ref":"Elemental.Select.html#select/1-attributes"},{"type":"function","title":"List item types - Elemental.Select.select/1","doc":"- If given as a list of strings (`[String.t]`) each option will use that value\n    as both it's label and value sent to from the dropdown.\n  - If give as a list of tuples (`[{String.t, String.t}]`), those tuples are expected\n    to be two strings, the first being the label to use, while the second is\n    expected to be the value to send from the dropdown.\n  - Mixing the two forms is allowed.\n  - Nested lists translate to option groups. See `Phoenix.HTML.Form.options_for_select/2`.\n\n* `prompt` (`:string`) - The prompt to display for the the select. Defaults to `nil`.\n* `name` (`:string`) - The name of the dropdown, if not given a random value is selected.\n* `value` (`:string`) - A value that is selected currently by the component.\n\n  Useful for either preselecting items or to maintaining selected\n  items state across rerenders.\n\n  Defaults to `nil`.\n* `color` (`:string`) - The select prompt color.Must be one of `\"ghost\"`, `\"neutral\"`, `\"primary\"`, `\"secondary\"`, `\"accent\"`, `\"info\"`, `\"success\"`, `\"warning\"`, or `\"error\"`.\n* `size` (`:string`) - The select prompt size.Must be one of `\"xs\"`, `\"sm\"`, `\"md\"`, `\"lg\"`, or `\"xl\"`.\n* `class` (`:string`) - Additional CSS classes to pass to the select. Defaults to `nil`.","ref":"Elemental.Select.html#select/1-list-item-types"},{"type":"module","title":"Elemental.Table","doc":"> Tabular data display components.","ref":"Elemental.Table.html"},{"type":"function","title":"Elemental.Table.body/1","doc":"","ref":"Elemental.Table.html#body/1"},{"type":"function","title":"Attributes - Elemental.Table.body/1","doc":"* `data` (`:any`) (required) - .\n* `row_id` (`:any`) - . Defaults to `nil`.","ref":"Elemental.Table.html#body/1-attributes"},{"type":"function","title":"Slots - Elemental.Table.body/1","doc":"* `cell` - . Accepts attributes:\n\n  * `id` (`:string`) - The identifier of this specific cell in the header row.\n  * `class` (`:string`) - The main CSS classes that will style this specific cell in the header row.","ref":"Elemental.Table.html#body/1-slots"},{"type":"function","title":"Elemental.Table.header/1","doc":"","ref":"Elemental.Table.html#header/1"},{"type":"function","title":"Attributes - Elemental.Table.header/1","doc":"* Global attributes are accepted.","ref":"Elemental.Table.html#header/1-attributes"},{"type":"function","title":"Slots - Elemental.Table.header/1","doc":"* `cell` - . Accepts attributes:\n\n  * `id` (`:string`) - The identifier of this specific cell in the header row.\n  * `class` (`:string`) - The main CSS classes that will style this specific cell in the header row.","ref":"Elemental.Table.html#header/1-slots"},{"type":"function","title":"Elemental.Table.table/1","doc":"","ref":"Elemental.Table.html#table/1"},{"type":"function","title":"Attributes - Elemental.Table.table/1","doc":"* Global attributes are accepted.","ref":"Elemental.Table.html#table/1-attributes"},{"type":"function","title":"Slots - Elemental.Table.table/1","doc":"* `inner_block` (required)","ref":"Elemental.Table.html#table/1-slots"},{"type":"module","title":"Elemental.Tooltip","doc":"> Exposing Daisy tooltips as Phoenix components.","ref":"Elemental.Tooltip.html"},{"type":"function","title":"Elemental.Tooltip.tooltip/1","doc":"Provides a Phoenix functional component wrapping the tooltip CSS based component.\n\nWrap a given inner slot with a `div` defining the tooltip attribute, and maps\nthe given attributes to useful tooltip properties.","ref":"Elemental.Tooltip.html#tooltip/1"},{"type":"function","title":"Attributes - Elemental.Tooltip.tooltip/1","doc":"* `tip` (`:string`) (required) - The text of the tooltip to display.\n* `position` (`:string`) - The positioning of the tooltip. Defaults to `\"top\"`.\n* `color` (`:string`) - The color to use for the tooltip. Defaults to `\"primary\"`.\n* `open` (`:boolean`) - Where to have the tooltip open immediately. Defaults to `false`.","ref":"Elemental.Tooltip.html#tooltip/1-attributes"},{"type":"function","title":"Slots - Elemental.Tooltip.tooltip/1","doc":"* `inner_block` (required)","ref":"Elemental.Tooltip.html#tooltip/1-slots"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}